@@ -1315,15 +1315,54 @@ sub check_current_record_object_against_a_rule {
 
 #########################################################################
 
+# SK, 2010-09-18
+# New error messages for bad attributes
+#
+
 sub bad_unknown_attribute {
 
-    my $where = $specification->{attribute_list}-> {$the_attribute} ;
+    use Text::LevenshteinXS qw( distance );
+
+    my( $suggest, @suggestions, $errstring, $template, $where, $i, $therest, $sw, $cluster, $maxerr );
+
+    $errstring = "Attribute '$the_attribute' is wrong or misplaced.";
+    
+    $template = $specification->{contexts}{$open_context_names_stack[1]}{TEMPLATE};
+    $where = $specification->{attribute_list}-> {$the_attribute} ;
     if ( $where ) {
-        error "Attribute '$the_attribute' is wrong or misplaced.".
-            " Could be correct if used in template of type $where.";
+        if ( $where =~ /$template/ ) {
+          $errstring .= " Can be used as part of a cluster in $template.";
+          for ( $i = $#open_context_names_stack; $i >= 1; $i-- ) {
+            if ( $the_attribute =~ /^$open_prefixes_stack[$i]/ ) {
+              # looks like it should be within this context look for matching switchers
+              $therest = $';
+              foreach $sw ( keys %{$specification->{contexts}{$open_context_names_stack[$i]}{SWITCHERS}} ) {
+                if ( $therest =~ /^$sw/ ) {
+                  $cluster = $specification->{contexts}{$open_context_names_stack[$i]}{SWITCHERS}{$sw};
+                  $errstring .= " Did you forget to start $cluster cluster with key attribute '$open_prefixes_stack[$i]$sw-$specification->{contexts}{$cluster}{KEY}'?";
+                }
+              }
+            }
+          }
+        } else {
+          $errstring .= " Could be correct if used in template of type $where.";
+        }
     } else {
-        error "Invalid (unknown) attribute '$the_attribute'";
+        $errstring = "Invalid (unknown) attribute '$the_attribute'.";
+        $maxerr = length( $the_attribute ) > 5 ? 2 : 1;
+        foreach my $attribute ( keys %{$specification->{attribute_list}} ) {
+            if ( distance( $attribute, $the_attribute ) <= $maxerr ) {
+                push @suggestions, $attribute;
+            }
+        }
+        $suggest = join( ' or ', @suggestions ) if @suggestions;
+        if ( $suggest ) {
+            $errstring .= " Did you mean '$suggest'?";
+        } else {
+            $errstring .= " Any 'word:' combination at the start of a line is interpreted as an attribute. Put a space at the beginning of the line to avoid this error.";
+        }
     }
+    error $errstring;
 }
 
 #########################################################################
@@ -1407,7 +1446,8 @@ sub update_statistics {
          and ( $attr_specification->{'max'} < $at_stat->{'CUR'} ) ) {
 #        error "You cannot repeat this attribute ('$the_attribute') here";
       if ( $the_attribute eq 'handle' ) {
-        error   "You cannot repeat 'handle' attribute in a template";
+        # SK 2010-09-18, update error message
+        error   "You cannot repeat 'handle' attribute in a template, did you forget to start a new template with 'Template-Type: ...'?";
       } else {
         warning "You cannot repeat this attribute ('$the_attribute') here";
       }
