@@ -14,8 +14,8 @@ package RePEc::Index::Update;
 #
 
 BEGIN { 
-#$VERSION = do { my @r=(q$Revision$=~/\d+/g); sprintf "%d."."%02d"x$#r,@r };
-# $Id$
+$VERSION = do { my @r=(q$Revision: 2.5 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r };
+# $Id: Update.pm,v 2.5 2007/02/14 20:59:56 ivan Exp $
 }
 
 use strict;
@@ -45,8 +45,6 @@ use Data::Dumper;
 use RePEc::Index::History::Handle;
 
 
-# use Storable qw( thaw );
-
 sub log_it {
     RePEc::Index::Log::log( @_ );
 }
@@ -379,7 +377,8 @@ sub check_file {
 #    $record -> present_set ( 1 );
     $readfile = 1;
 
-  } else {
+  } 
+  else {
     my $mark     = $record -> last_observed;
     my $lastread = $record -> last_read;
     my $previous_last_modified = $record -> last_modified;
